@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 """Benchmark listing all processes
 
@@ -8,15 +7,13 @@ Usage:
 """
 
 import os
+import sys
+import time
+
 
 MYDIR = os.path.dirname(os.path.abspath(__file__))
-
-import sys
-
 sys.path.insert(0, os.path.join(MYDIR, ".."))
 
-import time
-
 from px import px_process
 
 LAPS = 20
@@ -24,12 +21,12 @@ LAPS = 20
 
 def main():
     t0 = time.time()
-    for iteration in range(LAPS):
+    for _ in range(LAPS):
         px_process.get_all()
     t1 = time.time()
     dt_seconds = t1 - t0
 
-    print("Getting all processes takes {:.0f}ms".format(1000 * dt_seconds / LAPS))
+    print(f"Getting all processes takes {1000 * dt_seconds / LAPS:.0f}ms")
 
 
 if __name__ == "__main__":
