@@ -2,7 +2,10 @@
 
 set -eu -o pipefail
 
-MYDIR="$(cd "$(dirname "$0")"; pwd)"
+MYDIR="$(
+    cd "$(dirname "$0")"
+    pwd
+)"
 ROOTDIR="$MYDIR/.."
 ZIPFILE="$ROOTDIR/px.pex"
 export ZIPOPT="-9 -q"
@@ -14,14 +17,14 @@ WORKDIR="$(mktemp -d)"
 trap 'rm -rf "$ENVDIR" "$WORKDIR" "$ZIPFILE.tmp"' EXIT
 
 # Create a virtualenv in a temporary location
-virtualenv -p "$(command -v python)" "$ENVDIR"
+python3 -m venv "$ENVDIR"
 
 # shellcheck source=/dev/null
 . "$ENVDIR/bin/activate"
 pip install -r "$ROOTDIR/requirements.txt"
 
 # Set up file structure in our temporary directory
-echo 'import px.px; px.px.main()' > "$WORKDIR/__main__.py"
+echo 'import px.px; px.px.main()' >"$WORKDIR/__main__.py"
 
 # The main attraction!
 cp -a "$ROOTDIR/px" "$WORKDIR/"
@@ -38,6 +41,9 @@ cd "$WORKDIR"
 zip -r "$ZIPFILE.tmp" ./*
 
 # Add Python shebang, from: https://stackoverflow.com/a/10587688/473672
-(echo '#!/usr/bin/env python'; cat "$ZIPFILE.tmp") > "$ZIPFILE"
+(
+    echo '#!/usr/bin/env python3'
+    cat "$ZIPFILE.tmp"
+) >"$ZIPFILE"
 
 chmod a+x "$ZIPFILE"
