@@ -2,9 +2,11 @@
 
 import re
 import os.path
+import logging
 
-from typing import List
-from typing import Optional
+from typing import List, Optional
+
+LOG = logging.getLogger(__name__)
 
 
 # Match "[kworker/0:0H]", no grouping
@@ -76,6 +78,20 @@ def try_clarify_electron(commandline: str) -> Optional[str]:
     return None
 
 
+def faillog(commandline: str, parse_result: Optional[str]) -> str:
+    """
+    If successful, just return the result. If unsuccessful log the problem and
+    return the VM name.
+    """
+    if parse_result:
+        return parse_result
+
+    LOG.debug("Parsing failed, using fallback: <%s>", commandline)
+
+    vm = os.path.basename(to_array(commandline)[0])
+    return vm
+
+
 def get_command(commandline: str) -> str:
     """
     Extracts the command from the command line.
@@ -95,7 +111,7 @@ def get_command(commandline: str) -> str:
     command = os.path.basename(to_array(commandline)[0])
 
     if command.startswith("python") or command == "Python":
-        return get_python_command(commandline)
+        return faillog(commandline, get_python_command(commandline))
 
     if command == "Electron":
         clarified = try_clarify_electron(commandline)
@@ -103,48 +119,82 @@ def get_command(commandline: str) -> str:
             return clarified
 
     if command == "java":
-        return get_java_command(commandline)
+        return faillog(commandline, get_java_command(commandline))
 
     if command == "ruby":
         # Switches list inspired by ruby 2.3.7p456 --help output
-        return get_generic_script_command(
+        return faillog(
             commandline,
-            [
-                "-a",
-                "-d",
-                "--debug",
-                "--disable",
-                #
-                # Quickfix for #74, better implementations welcome!
-                # https://github.com/walles/px/issues/74
-                "-Eascii-8bit:ascii-8bit",
-                #
-                "-l",
-                "-n",
-                "-p",
-                "-s",
-                "-S",
-                "-v",
-                "--verbose",
-                "-w",
-                "-W0",
-                "-W1",
-                "-W2",
-                "--",
-            ],
+            get_generic_script_command(
+                commandline,
+                ignore_switches=[
+                    "-a",
+                    "-d",
+                    "--debug",
+                    "--disable",
+                    #
+                    # Quickfix for #74, better implementations welcome!
+                    # https://github.com/walles/px/issues/74
+                    "-Eascii-8bit:ascii-8bit",
+                    #
+                    "-l",
+                    "-n",
+                    "-p",
+                    "-s",
+                    "-S",
+                    "-v",
+                    "--verbose",
+                    "-w",
+                    "-W0",
+                    "-W1",
+                    "-W2",
+                    "--",
+                ],
+            ),
         )
 
     if command == "sudo":
-        return get_sudo_command(commandline)
+        return faillog(commandline, get_sudo_command(commandline))
+
+    if command in [
+        # NOTE: This list contains binaries that are mostly used with
+        # subcommands. Scripts (like brew.rb) are handled in
+        # get_generic_script_command().
+        #
+        # "gradle" and "mvn" are not handled at all, could be added to
+        # get_java_command().
+        "apt-get",
+        "apt",
+        "cargo",
+        "docker",
+        "docker-compose",
+        "git",
+        "go",
+        "npm",
+        "pip",
+        "pip3",
+        "rustup",
+    ]:
+        return faillog(commandline, get_with_subcommand(commandline))
+
+    if command == "terraform":
+        return faillog(
+            commandline, get_with_subcommand(commandline, ignore_switches=["-chdir"])
+        )
 
     if command == "node":
-        return get_generic_script_command(commandline, ["--max_old_space_size"])
+        return faillog(
+            commandline,
+            get_generic_script_command(
+                commandline, ignore_switches=["--max_old_space_size"]
+            ),
+        )
 
     if command in ["bash", "sh"]:
-        return get_generic_script_command(commandline)
+        return faillog(commandline, get_generic_script_command(commandline))
 
     if PERL_BIN.match(command):
-        return get_generic_script_command(commandline)
+        return faillog(commandline, get_generic_script_command(commandline))
 
     app_name_prefix = get_app_name_prefix(commandline)
     if is_human_friendly(command):
@@ -156,19 +206,24 @@ def get_command(commandline: str) -> str:
 
     command_split = command.split(".")
     if len(command_split) > 1:
+        command_suggestion = ""
         if len(command_split[-1]) > 4:
             # Pretend all the dots are a kind of path and go for the last
             # part only
-            command = command_split[-1]
+            command_suggestion = command_split[-1]
         else:
             # Assume last part is a file suffix (like ".exe") and take the
             # next to last part
-            command = command_split[-2]
+            command_suggestion = command_split[-2]
+        if len(command_suggestion) >= 5:
+            # Good enough!
+            command = command_suggestion
 
     return app_name_prefix + command
 
 
-def get_python_command(commandline: str) -> str:
+def get_python_command(commandline: str) -> Optional[str]:
+    """Returns None if we failed to figure out the script name"""
     array = to_array(commandline)
     array = list(filter(lambda s: s, array))
 
@@ -207,17 +262,18 @@ def get_python_command(commandline: str) -> str:
         if array[1] == "-m" and not array[2].startswith("-"):
             return os.path.basename(array[2])
 
-    return python
+    return None
 
 
-def get_sudo_command(commandline: str) -> str:
+def get_sudo_command(commandline: str) -> Optional[str]:
+    """Returns None if we failed to figure out the script name"""
     without_sudo = commandline[5:].strip()
     if not without_sudo:
         return "sudo"
 
     if without_sudo.startswith("-"):
         # Give up on options
-        return "sudo"
+        return None
 
     return "sudo " + get_command(without_sudo)
 
@@ -234,7 +290,8 @@ def prettify_fully_qualified_java_class(class_name: str) -> str:
     return split[-1]
 
 
-def get_java_command(commandline: str) -> str:
+def get_java_command(commandline: str) -> Optional[str]:
+    """Returns None if we failed to figure out the script name"""
     array = to_array(commandline)
     java = os.path.basename(array[0])
     if len(array) == 1:
@@ -248,16 +305,14 @@ def get_java_command(commandline: str) -> str:
 
         if state == "skip next":
             if component.startswith("-"):
-                # Skipping switches doesn't make sense. We're lost, fall back to
-                # just returning the command name
-                return java
+                # Skipping switches doesn't make sense. We're lost.
+                return None
             state = "scanning"
             continue
         if state == "return next":
             if component.startswith("-"):
-                # Returning switches doesn't make sense. We're lost, fall back
-                # to just returning the command name
-                return java
+                # Returning switches doesn't make sense. We're lost.
+                return None
             return os.path.basename(component)
         if state == "scanning":
             if component.startswith("-X"):
@@ -309,18 +364,40 @@ def get_java_command(commandline: str) -> str:
                 continue
             if component.startswith("-"):
                 # Unsupported switch, give up
-                return java
+                return None
             return prettify_fully_qualified_java_class(component)
 
         raise ValueError(f"Unhandled state <{state}> at <{component}> for: {array}")
 
     # We got to the end without being able to come up with a better name, give up
-    return java
+    return None
+
+
+def get_with_subcommand(
+    commandline: str, ignore_switches: Optional[List[str]] = None
+) -> Optional[str]:
+    array = to_array(commandline)
+
+    if ignore_switches is None:
+        ignore_switches = []
+    while len(array) > 1 and array[1].split("=")[0] in ignore_switches:
+        del array[1]
+
+    command = os.path.basename(array[0])
+    if len(array) == 1:
+        return command
+
+    if array[1].startswith("-"):
+        # Unknown option, help!
+        return command
+
+    return f"{command} {array[1]}"
 
 
 def get_generic_script_command(
     commandline: str, ignore_switches: Optional[List[str]] = None
-) -> str:
+) -> Optional[str]:
+    """Returns None if we failed to figure out the script name"""
     array = to_array(commandline)
 
     if ignore_switches is None:
@@ -333,7 +410,20 @@ def get_generic_script_command(
         return vm
 
     if array[1].startswith("-"):
-        # This is some option, we don't do options
-        return vm
+        # Unknown option, help!
+        return None
 
-    return os.path.basename(array[1])
+    script = os.path.basename(array[1])
+    if len(array) == 2:
+        # vm + script
+        return script
+    if script not in ["brew.rb", "yarn.js"]:
+        return script
+    script = os.path.splitext(script)[0]
+
+    subcommand = array[2]
+    if subcommand.startswith("-"):
+        # Unknown option before the subcommand
+        return script
+
+    return f"{script} {subcommand}"
