@@ -276,7 +276,7 @@ def test_get_command_ruby_switches():
         px_commandline.get_command(
             "/usr/bin/ruby -W0 /usr/local/bin/brew.rb install rust"
         )
-        == "brew.rb"
+        == "brew install"
     )
 
     # https://github.com/walles/px/issues/87
@@ -394,10 +394,43 @@ def test_get_homebrew_commandline():
                 ]
             )
         )
-        == "brew.rb"
+        == "brew upgrade"
     )
 
 
+def test_get_terraform_provider_commandline():
+    # Source: https://github.com/walles/px/issues/105
+    assert (
+        px_commandline.get_command(
+            ".terraform/providers/registry.terraform.io/heroku/heroku/4.8.0/darwin_amd64/terraform-provider-heroku_v4.8.0"
+        )
+        == "terraform-provider-heroku_v4.8.0"
+    )
+
+
+def test_get_terraform_commandline():
+    # Source: https://github.com/walles/px/issues/113
+    assert (
+        px_commandline.get_command("terraform -chdir=dev apply -target=abc123")
+        == "terraform apply"
+    )
+
+
+def test_get_go_commandline():
+    assert px_commandline.get_command("go build ./...") == "go build"
+    assert px_commandline.get_command("go --version") == "go"
+    assert px_commandline.get_command("/usr/local/bin/go") == "go"
+
+
+def test_get_git_commandline():
+    assert (
+        px_commandline.get_command("git clone git@github.com:walles/riff")
+        == "git clone"
+    )
+    assert px_commandline.get_command("git --version") == "git"
+    assert px_commandline.get_command("/usr/local/bin/git") == "git"
+
+
 def test_node_max_old_space():
     assert (
         px_commandline.get_command("node --max_old_space_size=4096 scripts/start.js")
