@@ -10,7 +10,7 @@ from . import testutils
 
 
 def test_adjust_cpu_times():
-    now = testutils.now()
+    now = testutils.local_now()
 
     current = [
         px_process.create_kernel_process(now),
@@ -100,18 +100,21 @@ def test_get_screen_lines_low_screen():
     baseline = px_process.get_all()
     poller = px_poller.PxPoller()
 
-    SCREEN_ROWS = 10
+    # We have to make up some number for "How low screens can we cope with?".
+    # Here's the number I made up.
+    SCREEN_ROWS = 11
+
     px_terminal._enable_color = True
-    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS)
+    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS, 99)
 
     # Top row should contain ANSI escape codes
-    CSI = u"\x1b["
-    assert u"CSI" in lines[0].replace(CSI, u"CSI")
+    CSI = "\x1b["
+    assert "CSI" in lines[0].replace(CSI, "CSI")
 
     assert len(lines) == SCREEN_ROWS
 
     # Last line should be decorated
-    assert u"CSI" in lines[-1].replace(CSI, u"CSI")
+    assert "CSI" in lines[-1].replace(CSI, "CSI")
 
 
 def test_get_screen_lines_high_screen():
@@ -120,16 +123,16 @@ def test_get_screen_lines_high_screen():
 
     SCREEN_ROWS = 100
     px_terminal._enable_color = True
-    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS)
+    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS, 99)
 
     # Top row should contain ANSI escape codes
-    CSI = u"\x1b["
-    assert u"CSI" in lines[0].replace(CSI, u"CSI")
+    CSI = "\x1b["
+    assert "CSI" in lines[0].replace(CSI, "CSI")
 
     assert len(lines) == SCREEN_ROWS
 
     # Last line should be decorated
-    assert u"CSI" in lines[-1].replace(CSI, u"CSI")
+    assert "CSI" in lines[-1].replace(CSI, "CSI")
 
 
 def test_get_screen_lines_with_many_launches():
@@ -146,7 +149,7 @@ def test_get_screen_lines_with_many_launches():
     poller._launchcounter_screen_lines = launchcounter.get_screen_lines()
 
     SCREEN_ROWS = 100
-    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS)
+    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS, 99)
 
     assert len(lines) == SCREEN_ROWS
 
@@ -156,6 +159,6 @@ def test_get_screen_lines_returns_enough_lines():
     poller = px_poller.PxPoller()
 
     SCREEN_ROWS = 100000
-    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS)
+    lines = px_top.get_screen_lines(baseline, poller, SCREEN_ROWS, 99)
 
     assert len(lines) == SCREEN_ROWS
